ete2.phylo.reconciliation

Package ete2 :: Package phylo :: Module reconciliation |
[hide private]
[frames] | no frames]

# Module reconciliation

source code

Functions | [hide private]
get_reconciled_tree(node, sptree, events) Returns the recoliation gene tree with a provided species topology | source code
_replace_on_template(orig_template, node) | source code
_get_expected_topology(t, species) | source code
_get_species_on_TOL(name) | source code

Variables | [hide private]
| __VERSION__ = ``'``ete2-2.0rev90``'``
| __package__ = ``'``ete2.phylo``'``